@@ -38,7 +38,8 @@ def predict_model(config: dict, fun_control: dict) -> Tuple[float, float]:
             import spotpython.light.testmodel as tm
             fun_control = fun_control_init(
                 _L_in=10,
-                _L_out=1,)
+                _L_out=1,
+                _torchmetric="mean_squared_error")
             dataset = Diabetes()
             set_control_key_value(control_dict=fun_control,
                                     key="data_set",
@@ -112,7 +113,9 @@ def predict_model(config: dict, fun_control: dict) -> Tuple[float, float]:
 
     # predictions = trainer.predict(model=model, datamodule=dm)
     # Changed in spotpython 0.18.12: use ckpt_path="last" to load the last checkpoint and not the model
-    predictions = trainer.predict(datamodule=dm, ckpt_path="last")
+    # predictions = trainer.predict(datamodule=dm, ckpt_path="last")
+    # Changed in spotpython 0.19.5: use ckpt_path="best" to load the best checkpoint and not the model
+    predictions = trainer.predict(datamodule=dm, ckpt_path="best")
 
     # # Load the last checkpoint
     # test_result = trainer.test(datamodule=dm, ckpt_path="last")
